import time
import pygame
import pygame.mixer as mixer
from gamestates import Game
from util import QuitException
import spritesheets
import controls
import sound


FPS_TARGET = 60.0

EVENTS = [
    pygame.KEYUP,
    pygame.KEYDOWN,
    pygame.MOUSEBUTTONUP,
    pygame.MOUSEBUTTONDOWN,
    pygame.JOYBUTTONUP,
    pygame.JOYBUTTONDOWN,
    pygame.QUIT,
]

def main():
    mixer.pre_init(frequency=44100)
    pygame.init()
    try:
        pygame.display.set_caption('10 Second Slaughter')
        screen = pygame.display.set_mode((640,480))

        spritesheets.init()
        controls.init()
        sound.init()

        game = Game(screen)

        last_update = time.time()
        last_render = time.time()
        while True:
            for ev in pygame.event.get(EVENTS):
                game.event(ev)

            now = time.time()
            dt = now-last_update
            game.update(dt)
            last_update = now

            game.render(screen)

            now = time.time()
            dt = now-last_render
            last_render = now
            if dt < 1/FPS_TARGET:
                pygame.time.wait(int(1000 * (1/FPS_TARGET - dt)))

    except QuitException:
        pass
    finally:
        pygame.quit()


if __name__ == '__main__':
    main()
